@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Role::ModuleMetadata; # git description: v0.002-6-g48c90d4
-# ABSTRACT: a role for plugins that use Module::Metadata
+package Dist::Zilla::Role::ModuleMetadata; # git description: v0.003-16-g7ff5130
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
+# ABSTRACT: A role for plugins that use Module::Metadata
 # KEYWORDS: zilla distribution plugin role metadata cache packages versions
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 use Moose::Role;
 use Module::Metadata 1.000005;
@@ -19,23 +19,26 @@ sub module_metadata_for_file
 {
     my ($self, $file) = @_;
 
+    Carp::croak('missing file argument for module_metadata_for_file') if not $file;
+
     # handle dzil v4 files by assuming no (or latin1) encoding
     my $encoded_content = $file->can('encoded_content') ? $file->encoded_content : $file->content;
 
     # We cache on the MD5 checksum to detect if the file has been modified
     # by some other plugin since it was last parsed, making our object invalid.
     my $md5 = md5($encoded_content);
-    return $CACHE{$file->name}{$md5} if $CACHE{$file->name}{$md5};
+    my $filename = $file->name;
+    return $CACHE{$filename}{$md5} if $CACHE{$filename}{$md5};
 
     open(
         my $fh,
         ($file->can('encoding') ? sprintf('<:encoding(%s)', $file->encoding) : '<'),
         \$encoded_content,
-    ) or $self->log_fatal('cannot open handle to ' . $file->name . ' content: ' . $!);
+    ) or $self->log_fatal([ 'cannot open handle to %s content: %s', $filename, $! ]);
 
-    $self->log_debug([ 'parsing %s for Module::Metadata', $file->name ]);
-    my $mmd = Module::Metadata->new_from_handle($fh, $file->name);
-    return ($CACHE{$file->name}{$md5} = $mmd);
+    $self->log_debug([ 'parsing %s for Module::Metadata', $filename ]);
+    my $mmd = Module::Metadata->new_from_handle($fh, $filename);
+    return ($CACHE{$filename}{$md5} = $mmd);
 }
 
 around dump_config => sub
@@ -45,7 +48,7 @@ around dump_config => sub
 
     $config->{+__PACKAGE__} = {
         'Module::Metadata' => Module::Metadata->VERSION,
-        version => __PACKAGE__->VERSION,
+        version => $VERSION,
     };
 
     return $config;
@@ -61,11 +64,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Role::ModuleMetadata - a role for plugins that use Module::Metadata
+Dist::Zilla::Role::ModuleMetadata - A role for plugins that use Module::Metadata
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -103,14 +106,6 @@ method returns a L<Module::Metadata> object for that file's content.
 Internally, this method caches these objects. If multiple plugins want an
 object for the same file, this avoids reparsing it.
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Role-ModuleMetadata>
-(or L<bug-Dist-Zilla-Role-ModuleMetadata@rt.cpan.org|mailto:bug-Dist-Zilla-Role-ModuleMetadata@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =over 4
@@ -121,11 +116,24 @@ L<Module::Metadata>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Role-ModuleMetadata>
+(or L<bug-Dist-Zilla-Role-ModuleMetadata@rt.cpan.org|mailto:bug-Dist-Zilla-Role-ModuleMetadata@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2015 by Karen Etheridge.
 
